Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1112)

Unified Diff: content/renderer/pepper/content_renderer_pepper_host_factory.cc

Issue 10917160: Add some logging to debug PPAPI permissions. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/common/pepper_plugin_registry.cc ('k') | ppapi/shared_impl/ppapi_permissions.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/pepper/content_renderer_pepper_host_factory.cc
diff --git a/content/renderer/pepper/content_renderer_pepper_host_factory.cc b/content/renderer/pepper/content_renderer_pepper_host_factory.cc
index 538fd9b285cb592f18739d7da3728c26b865ed35..bf84e355208597532514bf1bea0f7192a094077e 100644
--- a/content/renderer/pepper/content_renderer_pepper_host_factory.cc
+++ b/content/renderer/pepper/content_renderer_pepper_host_factory.cc
@@ -37,9 +37,12 @@ scoped_ptr<ResourceHost> ContentRendererPepperHostFactory::CreateResourceHost(
// TODO(brettw) when we support any public or private interfaces, put them in
// a separate switch above.
- // TODO(brettw) put back this dev check! This was removed to fix issue 138902
- // where the permissions for bundled Flash (but not Flash that you specify
- // on the command line, making it difficult to test) are incorrect.
+ // TODO(brettw) bug 147507: put back this dev check and remove the log! This
+ // was removed to fix issue 138902 where the permissions for bundled Flash
+ // (but not Flash that you specify on the command line, making it difficult
+ // to test) are incorrect.
+ LOG(INFO) << "ContentRendererPepperHostFactory::CreateResourceHost "
+ << "permissions = " << GetPermissions().GetBits();
/*if (GetPermissions().HasPermission(ppapi::PERMISSION_DEV))*/ {
switch (message.type()) {
case PpapiHostMsg_FileChooser_Create::ID:
« no previous file with comments | « content/common/pepper_plugin_registry.cc ('k') | ppapi/shared_impl/ppapi_permissions.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698